#   Copyright 2007,2008,2009,2011 Everyblock LLC, OpenPlans, and contributors
#
#   This file is part of ebpub
#
#   ebpub is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   ebpub is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with ebpub.  If not, see <http://www.gnu.org/licenses/>.
#

#There are no models, but `manage.py test` needs a models.py to find tests.

def is_instance_of_model(obj, model):
    """
    isinstance(foo, model) seems to work *sometimes* with django models,
    but not always; no idea what's going on there.
    This should always work.
    """
    return (isinstance(obj, model)
            or type(obj) is model
            or model in obj.__class__.__bases__)
